@@ -64,7 +64,7 @@ def do_count(fnc, attr_name, not_attr_name, attr_plural, print_attr, print_not_a
         print(f'[{count_attr}] projects {attr_plural}')
 
 
-def do_for_all_projects(fnc) -> None:
+def do_for_all_projects(fnc, show_output) -> None:
     count = 0
     count_not_found = 0
     count_error = 0
@@ -77,13 +77,28 @@ def do_for_all_projects(fnc) -> None:
         count += 1
         if os.path.isdir(project_dir):
             os.chdir(project_dir)
-            ret = fnc(project_name, project_dir)
-            if ret:
-                count_error += 1
-            else:
+            try:
+                ret = fnc(project_name, project_dir)
                 count_ok += 1
-            if ConfigDebug.verbose:
-                print('OK')
+                if ConfigDebug.verbose:
+                    print('OK')
+            # this is one of the rare cases in which we really want to catch all exceptions.
+            # pylint: disable=broad-except
+            # noinspection PyBroadException
+            except Exception:
+                count_error += 1
+                if ConfigDebug.verbose:
+                    print('ERROR')
+            if ConfigOutput.terse:
+                if show_output:
+                    print(f'{project_name} {ret}')
+                else:
+                    print(project_name)
+            else:
+                if show_output:
+                    print(f'project [{project_name}] at [{project_dir}] output [{ret}]')
+                else:
+                    print(f'project [{project_name}] at [{project_dir}]')
             os.chdir(orig_dir)
         else:
             if ConfigDebug.verbose:
@@ -96,6 +111,16 @@ def do_for_all_projects(fnc) -> None:
         print(f'[{count_ok}] ok')
 
 
+def print_projects_that_return_true(fnc) -> None:
+    orig_dir = os.getcwd()
+    for (project_name, project_dir) in projects(sort=ConfigMain.sort):
+        if os.path.isdir(project_dir):
+            os.chdir(project_dir)
+            if fnc(project_name, project_dir):
+                print(project_name)
+            os.chdir(orig_dir)
+
+
 def is_dirty(repo) -> bool:
     return repo.is_dirty()
 
@@ -230,12 +255,14 @@ def do_status(project_name: str, _project_dir: str) -> int:
     return do_status_msg(project_name=project_name, msg=msg)
 
 
-def do_dirty(project_name: str, project_dir: str) -> int:
-    if ConfigOutput.terse:
-        msg = project_name
-    else:
-        msg = f"project [{project_name}] at directory [{project_dir}]"
-    return do_status_msg(project_name=project_name, msg=msg)
+def do_dirty(_project_name: str, _project_dir: str) -> int:
+    args = ['git', 'status', '--porcelain']
+    if ConfigDebug.git_verbose:
+        args.append('--verbose')
+    if ConfigDebug.git_quiet:
+        args.append('--quiet')
+    output = subprocess.check_output(args, stderr=subprocess.DEVNULL)
+    return output.decode() != ''
 
 
 def do_print(project_name: str, project_dir: str) -> None:
